@@ -11,7 +11,7 @@ use base 'Exporter';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -56,7 +56,7 @@ Readonly our $PINTO_SERVER_TEST_ROOT =>
 
 #------------------------------------------------------------------------------
 
-Readonly our $PINTO_SERVER_RESPONSE_LINE_PREFIX => 'SERVER: ';
+Readonly our $PINTO_SERVER_RESPONSE_LINE_PREFIX => '## ';
 
 Readonly our $PINTO_SERVER_RESPONSE_PROLOGUE =>
     "${PINTO_SERVER_RESPONSE_LINE_PREFIX}Protocol: 0.01";
@@ -97,7 +97,7 @@ Pinto::Constants - Constants used across the Pinto utilities
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 AUTHOR
 
